<?php
namespace wppgpcproduct_nacespace;

use wppgpcproduct_nacespace\PageSettings\Page_Settings;
define( "WPPGPC_ASFSK_ASSETS_PUBLIC_DIR_FILE", plugin_dir_url( __FILE__ ) . "assets/public" );
define( "WPPGPC_ASFSK_ASSETS_ADMIN_DIR_FILE", plugin_dir_url( __FILE__ ) . "assets/admin" );

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Classwppgpcproduct {

	private static $_instance = null;

	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	public function wppgpc_admin_editor_scripts() {
		add_filter( 'script_loader_tag', [ $this, 'wppgpc_admin_editor_scripts_as_a_module' ], 10, 2 );
	}

	public function wppgpc_admin_editor_scripts_as_a_module( $tag, $handle ) {
		if ( 'wppgpc_product_editor' === $handle ) {
			$tag = str_replace( '<script', '<script type="module"', $tag );
		}

		return $tag;
	}

	private function include_widgets_files() {
		require_once( __DIR__ . '/widgets/wppgpc-product-widgets.php' );
	}

	public function wppgpc_register_widgets() {
		// Its is now safe to include Widgets files
		$this->include_widgets_files();

		// Register WidgetsF
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\wppgpc_product_widgets());
	}

	private function add_page_settings_controls() {
		require_once( __DIR__ . '/page-settings/wppgpc-product-manager.php' );
		new Page_Settings();
	}

	// Register Category
	function wppgpc_new_add_elementor_widget_categories( $elements_manager ) {

		$elements_manager->add_category(
			'wppgpc-product-category',
			[
				'title' => esc_html__( 'Product Carousel', 'wppgpc-product-td' ),
				'icon' => 'eicon-person',
			]
		);
	}

	public function wppgpc_all_assets_style_for_the_public(){
		$wppgpc_cnd_link = 'https://bwd-elementor-addons-pro.netlify.app/grid-product-casousel/';
		wp_enqueue_style( 'product-grid-carousel-min-style', $wppgpc_cnd_link.'owl.carousel.min.css' );
		wp_enqueue_style( 'product-grid-carousel-default-style', $wppgpc_cnd_link.'owl.theme.default.min.css' );
		wp_enqueue_style( 'product-grid-carousel-style', $wppgpc_cnd_link.'style.css' );
		wp_enqueue_script( 'product-grid-carousel-min-interactive', $wppgpc_cnd_link.'owl.carousel.min.js' );
		wp_enqueue_script( 'product-grid-carousel-interactive', $wppgpc_cnd_link.'main.js' );
	}

	public function wppgpc_all_assets_for_elementor_editor_admin(){
		$all_css_js_file = array(
            'product-admin-icon' => array('wppgpc_path_admin_define'=>WPPGPC_ASFSK_ASSETS_ADMIN_DIR_FILE . '/icon.css'),
        );
        foreach($all_css_js_file as $handle => $fileinfo){
            wp_enqueue_style( $handle, $fileinfo['wppgpc_path_admin_define'], null, '2.1', 'all');
        }
	}
	
	public function __construct() {

		// For public assets
		add_action('wp_enqueue_scripts', [$this, 'wppgpc_all_assets_style_for_the_public']);

		// For Elementor Editor
		add_action('elementor/editor/before_enqueue_scripts', [$this, 'wppgpc_all_assets_for_elementor_editor_admin']);
		
		// Register Category
		add_action( 'elementor/elements/categories_registered', [ $this, 'wppgpc_new_add_elementor_widget_categories' ] );

		// Register widgets
		add_action( 'elementor/widgets/widgets_registered', [ $this, 'wppgpc_register_widgets' ] );

		// Register editor scripts
		add_action( 'elementor/editor/after_enqueue_scripts', [ $this, 'wppgpc_admin_editor_scripts' ] );
	}
}

// Instantiate Plugin Class
Classwppgpcproduct::instance();